==> mule-datasense-4.1.3-hf1-sources.jar: org/mule/datasense/impl/phases/typing/resolver/SetVariableTypeResolver.java <==
package org.mule.datasense.impl.phases.typing.resolver;

import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.event.MuleEventExprBuilder;
import org.mule.datasense.impl.model.event.SimpleExprBuilder;
import org.mule.datasense.impl.model.event.ValueExprBuilder;
import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitor;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitorContext;
import org.mule.datasense.impl.util.ExpressionLanguageUtils;
import org.mule.datasense.impl.util.extension.ExtensionUtils;
import org.mule.runtime.config.internal.model.ComponentModel;

import java.util.Optional;
import java.util.function.Consumer;

import static java.util.Optional.ofNullable;

public class SetVariableTypeResolver extends SetDataTypeResolver {

  private final static String FIELD_VALUE = "value";
  private final static String FIELD_VARIABLE = "variableName";
  private final static String TYPE_DEFAULT_EXPRESSION = "''";

  @Override
  protected Consumer<MuleEventExprBuilder> getMuleEventExprBuilderConsumer(MessageProcessorNode messageProcessorNode,
                                                                           EventType inputEventType,
                                                                           TypingMuleAstVisitor typingMuleAstVisitor,
                                                                           TypingMuleAstVisitorContext visitorContext) {
    return (muleEventExprBuilder) -> {
      getVarDeclName(messageProcessorNode).ifPresent(variableName -> {
        final String expression = getVarDeclValue(messageProcessorNode);
        muleEventExprBuilder.variable(variableName, v -> {
          final SimpleExprBuilder exprBuilder = new SimpleExprBuilder(expression);
          final ComponentModel componentModel = messageProcessorNode.getComponentModel();
          ExtensionUtils.findMimeType(componentModel).ifPresent(exprBuilder::mimeType);
          v.value(new ValueExprBuilder(exprBuilder));
        });
      });
    };
  }

  protected Optional<String> getVarDeclName(MessageProcessorNode messageProcessorNode) {
    return ofNullable(messageProcessorNode.getComponentModel().getParameters().get(FIELD_VARIABLE));
  }

  protected String getVarDeclValue(MessageProcessorNode messageProcessorNode) {
    return ExpressionLanguageUtils.extractExpression(messageProcessorNode.getComponentModel().getParameters().get(FIELD_VALUE))
        .orElse(TYPE_DEFAULT_EXPRESSION);
  }
}

==> mule-datasense-4.1.5-hf1-sources.jar: org/mule/datasense/impl/phases/typing/resolver/SetVariableTypeResolver.java <==
package org.mule.datasense.impl.phases.typing.resolver;

import org.mule.datasense.impl.model.ast.MessageProcessorNode;
import org.mule.datasense.impl.model.event.MuleEventExprBuilder;
import org.mule.datasense.impl.model.event.ValueExprBuilder;
import org.mule.datasense.impl.model.types.EventType;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitor;
import org.mule.datasense.impl.phases.typing.TypingMuleAstVisitorContext;

import java.util.Optional;
import java.util.function.Consumer;

import static java.util.Optional.ofNullable;

public class SetVariableTypeResolver extends SetMuleEventDataTypeResolver {

  private final static String FIELD_VARIABLE = "variableName";

  @Override
  protected Consumer<MuleEventExprBuilder> getMuleEventExprBuilderConsumer(MessageProcessorNode messageProcessorNode,
                                                                           EventType inputEventType,
                                                                           TypingMuleAstVisitor typingMuleAstVisitor,
                                                                           TypingMuleAstVisitorContext visitorContext) {
    return (muleEventExprBuilder) -> {
      getVarDeclName(messageProcessorNode).ifPresent(variableName -> {
        muleEventExprBuilder.variable(variableName, v -> {
          v.value(new ValueExprBuilder(resolveExprBuilder(messageProcessorNode)));
        });
      });
    };
  }

  private Optional<String> getVarDeclName(MessageProcessorNode messageProcessorNode) {
    return ofNullable(messageProcessorNode.getComponentModel().getParameters().get(FIELD_VARIABLE));
  }
}
